Index: tests/ClipCacheTest.cpp |
diff --git a/tests/ClipCacheTest.cpp b/tests/ClipCacheTest.cpp |
index 3d3fa95c0390ed82f53de9ec99b6272eb126f0a1..0e5fe1e4ac8a0852fdb8fc764cff4e9533864790 100644 |
--- a/tests/ClipCacheTest.cpp |
+++ b/tests/ClipCacheTest.cpp |
@@ -84,17 +84,17 @@ |
REPORTER_ASSERT(reporter, screen == devStackBounds); |
REPORTER_ASSERT(reporter, isIntersectionOfRects); |
// wrap the SkClipStack in a GrClip |
GrClip clipData; |
clipData.setClipStack(&stack); |
- SkIRect devGrClipBound; |
+ SkIRect devGrClipDataBound; |
clipData.getConservativeBounds(texture, |
- &devGrClipBound, |
+ &devGrClipDataBound, |
&isIntersectionOfRects); |
- // make sure that GrClip is behaving itself |
- REPORTER_ASSERT(reporter, intScreen == devGrClipBound); |
+ // make sure that GrClipData is behaving itself |
+ REPORTER_ASSERT(reporter, intScreen == devGrClipDataBound); |
REPORTER_ASSERT(reporter, isIntersectionOfRects); |
} |
@@ -84,17 +84,17 @@ |
REPORTER_ASSERT(reporter, screen == devStackBounds); |
REPORTER_ASSERT(reporter, isIntersectionOfRects); |
- // wrap the SkClipStack in a GrClip |
+ // wrap the SkClipStack in a GrClipData |
GrClip clipData; |
clipData.setClipStack(&stack); |